@@ -8,9 +8,9 @@ import logging
 import operator
 
 try:
-    from importlib import metadata
+    from importlib import metadata  # type: ignore
 except ImportError:
-    import importlib_metadata as metadata
+    import importlib_metadata as metadata  # type: ignore
 
 from . import credentials, errors, util
 from .util import properties
@@ -196,7 +196,7 @@ def _load_plugins():
 
     `initialize_func` is optional, but will be invoked if callable.
     """
-    entry_points = metadata.entry_points()['keyring.backends']
+    entry_points = metadata.entry_points().get('keyring.backends', [])
     for ep in entry_points:
         try:
             log.debug('Loading %s', ep.name)
