@@ -1,10 +1,10 @@
 import os
 import abc
 
-from .py27compat import add_metaclass
+__metaclass__ = type
 
-@add_metaclass(abc.ABCMeta)
-class Credential(object):
+
+class Credential(metaclass=abc.ABCMeta):
     """Abstract class to manage credentials
     """
 
@@ -16,6 +16,7 @@ class Credential(object):
     def password(self):
         return None
 
+
 class SimpleCredential(Credential):
     """Simple credentials implementation
     """
@@ -32,6 +33,7 @@ class SimpleCredential(Credential):
     def password(self):
         return self._password
 
+
 class EnvironCredential(Credential):
     """Source credentials from environment variables.
        Actual sourcing is deferred until requested.
@@ -46,7 +48,7 @@ class EnvironCredential(Credential):
         """
         value = os.environ.get(env_var)
         if not value:
-            raise ValueError('Missing environment variable:%s' %env_var)
+            raise ValueError('Missing environment variable:%s' % env_var)
         return value
 
     @property
